====================
time_space_reductions
====================


.. image:: https://img.shields.io/pypi/v/time_space_aggregations.svg
        :target: https://pypi.python.org/pypi/time_space_reductions

.. image:: https://img.shields.io/travis/PhilipeRLeal/time_space_aggregations.svg
        :target: https://travis-ci.org/PhilipeRLeal/time_space_reductions

.. image:: https://readthedocs.org/projects/time-space-match-ups/badge/?version=latest
        :target: https://time-space-match-ups.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/PhilipeRLeal/time_space_aggregations/shield.svg
     :target: https://pyup.io/repos/github/PhilipeRLeal/time_space_reductions/
     :alt: Updates



This library operates Space-Time Match-Up operations over Netcdf-Xarray datasets and Geopandas-GeoDataFrames. 
It is a mandatoryr step for areas of study as geography, epidemiology, sociology, remote sensing, ecology, etc.


* Free software: MIT license
* Documentation: https://time-space-match-ups.readthedocs.io.


Features
--------

* TODO

	# parallelize the aggregation functions.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
